@@ -156,7 +156,7 @@ async def parse_message(message: dict):
             error=False,
             progress=0,
             color="green",
-            status="Accepted",
+            status="Waiting",
             details=[],
         )
 
@@ -180,6 +180,9 @@ async def parse_message(message: dict):
             Detail(name="Time  ", description=str(data["time"]) + " ms"),
         ]
 
+        if "subtask_score" in data:
+            details.append(Detail(name="Score ", description=str(data["subtask_score"])))
+
         return Message(
             keep_alive=False,
             error=False,
